#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 irc-core
version:              2.13
visibility:           public
id:                   irc-core-2.13-2lJS6NoouzE49yRgupmc9O
key:                  irc-core-2.13-2lJS6NoouzE49yRgupmc9O
license:              ISC
copyright:            2016 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/irc-core
synopsis:             IRC core library for glirc
description:
    IRC core library for glirc
    .
    The glirc client has been split off into <https://hackage.haskell.org/package/glirc>

category:             Network
abi:                  b7d68926bf20234de7bc9374d33693d4
exposed:              True
exposed-modules:
    Irc.Codes Irc.Commands Irc.Identifier Irc.Message Irc.Modes
    Irc.RateLimit Irc.RawIrcMsg Irc.UserInfo

hidden-modules:       View
import-dirs:          /usr/lib/ghc-9.6.6/site-local/irc-core-2.13
library-dirs:         /usr/lib/ghc-9.6.6/site-local/irc-core-2.13
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/irc-core-2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-irc-core
hs-libraries:         HSirc-core-2.13-2lJS6NoouzE49yRgupmc9O
depends:
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    primitive-0.9.1.0-MBLhlhjxKECZedf7vLmE9 text-2.0.2 time-1.12.2
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:   /usr/share/doc/haskell-irc-core/html/irc-core.haddock
haddock-html:         /usr/share/doc/haskell-irc-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

